# simfail runs on bare metal but not on Koji
%bcond_with check

%global toolchain clang

%global libbpf_url https://github.com/libbpf/libbpf
%global libbpf_version 1.0.1

Name:           retsnoop
Version:        0.9.1
Release:        %autorelease
Summary:        A tool for investigating kernel error call stacks

License:        BSD-2-Clause
URL:            https://github.com/anakryiko/retsnoop
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{libbpf_url}/archive/v%{libbpf_version}/libbpf-%{libbpf_version}.tar.gz
# bump dependencies
Patch:          %{name}-bump-dependencies.diff
Patch:          %{name}-add-make-install.diff

# has a Rust component
# ExclusiveArch:  %%{rust_arches}
# currently fails to build on non-x86_64
ExclusiveArch:  x86_64

BuildRequires:  clang
BuildRequires:  make
BuildRequires:  rust-packaging >= 21
# libbpf deps
BuildRequires:  elfutils-libelf-devel

# upstream does not support dynamic linking
Provides:       bundled(libbpf) = %{libbpf_version}

%description
retsnoop is BPF-based tool that is meant to help debugging kernel issues. It
allows to capture call stacks of kernel functions that return errors (NULL or
-Exxx) and emits every such detected call stack, along with the captured
results.


%prep
%autosetup -p1
# provide the libbpf version we specify rather than using git submodule
tar xf %{SOURCE1}
rmdir libbpf
mv libbpf-%{libbpf_version} libbpf
# Rust parts
# the path is hardcoded, make sure Cargo.toml is found in the expected place
ln -s sidecar/Cargo.toml .
# the checksums in the lock file might not match
rm sidecar/Cargo.lock
%cargo_prep

%generate_buildrequires
%cargo_generate_buildrequires


%build
cd sidecar
%cargo_build
cd -
%make_build -C src


%install
%make_install -C src prefix=%{_prefix}


%if %{with check}
%check
./src/simfail -a
%endif


%files
%license LICENSE
%doc README.md TODO.md
%{_bindir}/retsnoop
%{_bindir}/simfail


%changelog
%autochangelog
